@@ -1,7 +1,7 @@
 #![allow(unused_parens)]
 use compact_str::CompactStr;
 use itertools::Itertools;
-use reqwest::Error;
+pub use reqwest::Error;
 use serde::de::DeserializeOwned;
 
 mod model;
@@ -49,7 +49,6 @@ impl Client {
 			self.language,
 			args.iter().map(|(k, v)| compact_str_url(k, v)).join("&")
 		);
-		dbg!(&url);
 		self.http.get(url).send().await?.json().await
 	}
 
